@@ -3,7 +3,7 @@
 from deployer import std
 from deployer.cli import HandlerType
 from deployer.daemonize import daemonize
-from deployer.shell import Shell, ShellHandler, GroupHandler
+from deployer.shell import Shell, ShellHandler
 from deployer.loggers import LoggerInterface
 from deployer.loggers.default import DefaultLogger, IndentedDefaultLogger
 from deployer.pty import Pty
@@ -18,8 +18,6 @@ import datetime
 import getpass
 import os
 import pickle
-import random
-import string
 import sys
 
 __all__ = ('start',)
@@ -53,7 +51,7 @@ class NewShell(ShellHandler):
     is_leaf = True
     handler_type = SocketHandlerType()
 
-    def __call__(self, context):
+    def __call__(self):
         print 'Opening new window...'
         self.shell.session.openNewShellFromThread()
 
@@ -61,14 +59,14 @@ class Jobs(ShellHandler):
     is_leaf = True
     handler_type = SocketHandlerType()
 
-    def __call__(self, context):
+    def __call__(self):
         print ' TODO: show running jobs...' # TODO
 
 class Monitor(ShellHandler):
     is_leaf = True
     handler_type = SocketHandlerType()
 
-    def __call__(self, context):
+    def __call__(self):
         # Open monitor in new pane.
         def monitor(pty):
             logger = IndentedDefaultLogger(pty.stdout)
@@ -298,19 +296,17 @@ class Connection(object):
                 d = threads.deferToThread(thread, f, conn)
 
                 # Attach thread-done callbacks
+                @d.addCallback
                 def done(result):
                     # Save result in correct slot.
                     results[index] = result
                     countDown()
 
+                @d.addErrback
                 def err(failure):
                     results[index] = str(failure)
                     countDown()
 
-                # Attach callbacks to these threads.
-                d.addCallback(done)
-                d.addErrback(err)
-
             while connections:
                 conn = connections.pop()
                 f = funcs.pop()
