@@ -9,8 +9,6 @@ from deployer.pty import Pty
 from deployer.shell import Shell, ShellHandler, GroupHandler, BuiltinType
 
 import codecs
-import datetime
-import getpass
 import os
 import random
 import signal
@@ -47,7 +45,7 @@ class HistoryList(ShellHandler):
     is_leaf = True
     handler_type = BuiltinType()
 
-    def __call__(self, context):
+    def __call__(self):
         # Show all entries
         for i, entry in enumerate(self.shell.history):
             print self._color_history_entry(i+1, entry)
@@ -75,7 +73,7 @@ class HistoryShowEntry(ShellHandler):
     def __init__(self, entry):
         self.entry = entry
 
-    def __call__(self, context):
+    def __call__(self):
         for r in self.entry.result:
             print TracePrinter(r.trace).print_color()
 
@@ -97,7 +95,7 @@ class HistoryShow(ShellHandler):
 
 
 class HistoryChildEntry(HistoryShowEntry):
-    def __call__(self, context):
+    def __call__(self):
         for r in self.entry.result:
             for io in r.trace.all_io:
                 sys.stdout.write(io)
@@ -184,7 +182,6 @@ def start(settings):
     settings = settings()
 
     # Loggers
-    username = getpass.getuser()
     logger = create_logger()
     history_logger = HistoryLogger()
     extra_loggers = settings.Meta.extra_loggers
