@@ -226,18 +226,14 @@ class ServiceDescriptor(object):
 
 
 class PropertyDescriptor(object):
-    def __init__(self, fget):
-        self.fget = fget
+    def __init__(self, attribute):
+        self.attribute = attribute
 
     def __get__(self, instance, owner):
         if instance:
-            return Action(instance, self.fget, is_property=True)
+            return Action(instance, self.attribute.fget, is_property=True)
         else:
-            # TODO: refactor to return what was originally assigned to the
-            #       service class. (This is required for dynamically
-            #       assigning/retreiving properties of Service classes  which
-            #       were already initialized before.)
-            return property(self.fget)
+            return self.attribute
 
 
 class QueryDescriptor(object):
@@ -263,7 +259,7 @@ class QueryDescriptor(object):
         if instance:
             return Action(instance, run, is_property=True)
         else:
-            raise AttributeError("Don't retrieve queries from the class object. Use instance.query_name")
+            return self.query
 
 
 class ServiceBase(type):
@@ -360,8 +356,7 @@ class ServiceBase(type):
             if isinstance(attribute, required_property):
                 attribute.name = attr_name
                 attribute.owner = service_name
-            attribute.fget.__name__ = 'property:%s' % attr_name
-            return PropertyDescriptor(attribute.fget)
+            return PropertyDescriptor(attribute)
 
         # Query objects are like properties and should also be
         # wrapped into a descriptor
@@ -579,30 +574,34 @@ class Env(object):
         subservice = self._service[name]
         return Env(subservice,self._pty, self._logger, self._is_sandbox)
 
-    def initialize_service(self, service_class, **mappings):
+    def initialize_service(self, service_class, mappings=None, name=None):
         """
         Dynamically initialize a service from within another service.
         This will make sure that the service class is initialized with the
         correct logger, sandbox and pty settings.
 
         - service_class, on object, inheriting from Service
-        - **mappings: a dict which maps the roles on host containers (or Host
+        - mappings: a dict which maps the roles on host containers (or Host
                       instances)
+        - name: custome name for this service.
 
         Note that when the service_class has a 'Hosts' definition inside,
         this will always get priority above **mappings.
         """
-        # Transform mappings
-        for role in mappings:
-            if isinstance(mappings[role], Host):
-                # TODO: decide whether we want to accept a Host class, or Host
-                # instance here. Maybe there's even no reason to not allow both.
-                mappings[role] = [ mappings[role] ]
-            else:
-                mappings[role] = mappings[role]._all
+        mappings = mappings or { }
+        name = name or service_class.__name__
+
+        # Transform mappings (can both be Host classes, or host container objects.)
+        for role, v in mappings.items():
+            if isclass(v) and issubclass(v, Host):
+                mappings[role] = [ v.get_instance() ]
+            elif isinstance(v, (list, tuple)):
+                mappings[role] = [ i.get_instance() for i in v ]
+            elif isinstance(v, HostsContainer):
+                mappings[role] = v._all
 
         # Initialize service
-        service_instance = service_class(HostsContainer(mappings), creator_service=self._service)
+        service_instance = service_class(HostsContainer(mappings), creator_service=self._service, name=name)
 
         # Wrap in Env
         return Env(service_instance, self._pty, self._logger, self._is_sandbox)
